'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

/**
 *
 * 根据key获取url中的参数，默认从search取,也支持从整个url中获取
 * @category  url
 * @param {string} [url=window.location.href]
 * @param {string} key 获取的参数key值
 * @returns {string}
 * @author hzxiongxu
 * @date 20210602
 *
 */
function getUrlParams(key, url) {
    if (url === void 0) { url = window.location.href; }
    var reg = new RegExp("(^|&|\\?)" + key + "=([^&^#]*)", 'i');
    var r = url.match(reg);
    if (r != null) {
        return decodeURIComponent(r[2]);
    }
    return '';
}
/**
 *
 * 获取url所有参数
 * @category  url
 * @param {string} [url=window.location.href]
 * @return {*}  {Record<string, any>}
 * @author hzxiongxu
 * @date 20210602
 */
function getAllUrlParams(url) {
    if (url === void 0) { url = window.location.href; }
    var params = {};
    var reg = new RegExp("\\?([^#]+)($|#)", 'i');
    var r = url.match(reg);
    if (r !== null) {
        r[1].split('&').forEach(function (item) {
            var q = item.split('=');
            if (q.length === 2) {
                params[q[0]] = decodeURIComponent(q[1]);
            }
        });
    }
    return params;
}
/**
 *
 * 给url添加参数,不改变参数的顺序，向后追加，如果有同名的则直接更改
 * @export
 * @category  url
 * @param {Record<string, any>} params 添加的参数，允许同时添加多个
 * @param {boolean} [isCover=true] 是否覆盖原来已有的参数，默认为覆盖
 * @param {*} [url=window.location.href] url，默认为当前页面的url
 * @return {*}  {string}
 * @author hzxiongxu
 * @date 20210602
 */
function addUrlParams(params, url, isCover) {
    if (url === void 0) { url = window.location.href; }
    if (isCover === void 0) { isCover = true; }
    var reg = new RegExp("\\?([^#]+)($|#)", 'i');
    var r = url.match(reg);
    // 本来就有参数的case
    if (r !== null) {
        // 如果不覆盖，那就删除现在的参数，不用对象合并的方式，是为了不改变原有的参数顺序
        if (!isCover) {
            for (var key in params) {
                if (("&" + r[1]).indexOf("&" + key + "=") !== -1) {
                    delete params[key];
                }
            }
        }
        return url.replace(/\?[^#]+/, "?" + r[1] + "&" + _ObjectToUrlParams(params));
    }
    else {
        //  默认参数还是不要加到hash上了
        if (url.indexOf('#') === -1) {
            return url + "?" + _ObjectToUrlParams(params);
        }
        else {
            var hashArr = url.split('#');
            return hashArr[0] + "?" + _ObjectToUrlParams(params) + "#" + hashArr[1];
        }
    }
}
/**
 *
 * 从url中删除指定的参数
 * @export
 * @category  url
 * @param {string} key
 * @param {*} [url=window.location.href]
 * @return {*}  {string}
 */
function delUrlParams(key, url) {
    if (url === void 0) { url = window.location.href; }
    var reg = new RegExp("(^|&|\\?)" + key + "=([^&^#]*)", 'i');
    var r = url.match(reg);
    if (r != null) {
        // 如果上一位是“？”不能直接 删除
        if (r[1] === '?') {
            url = url.replace(r[0].substr(1), '');
        }
        else {
            url = url.replace(r[0], '');
        }
    }
    // 删除掉多余的问题
    url = url.replace('?&', '?').replace('?#', '#');
    if (url.substr(-1) === '?') {
        url = url.replace('?', '');
    }
    return url;
}
/**
 *
 *  将对象转成url参数
 * @param {Record<string, any>} params
 * @category  url
 * @private
 * @return {*}  {string}
 * @author hzxiongxu
 * @date 20210602
 */
function _ObjectToUrlParams(params) {
    // 此处的entries 不引入polyfill 不会转义，但是引入变大了，需要放弃此类写法吗？
    return Object.entries(params).reduce(function (initString, _a) {
        var key = _a[0], value = _a[1];
        return initString ? initString + "&" + key + "=" + encodeURIComponent(value) : key + "=" + encodeURIComponent(value);
    }, '');
}

exports.addUrlParams = addUrlParams;
exports.delUrlParams = delUrlParams;
exports.getAllUrlParams = getAllUrlParams;
exports.getUrlParams = getUrlParams;
