/**
 *
 * 根据key获取url中的参数，默认从search取,也支持从整个url中获取
 * @category  url
 * @param {string} [url=window.location.href]
 * @param {string} key 获取的参数key值
 * @returns {string}
 * @author hzxiongxu
 * @date 20210602
 *
 */
function getUrlParams(key, url) {
    if (url === void 0) { url = window.location.href; }
    var reg = new RegExp("(^|&|\\?)" + key + "=([^&^#]*)", 'i');
    var r = url.match(reg);
    if (r != null) {
        return decodeURIComponent(r[2]);
    }
    return '';
}
/**
 *
 * 获取url所有参数
 * @category  url
 * @param {string} [url=window.location.href]
 * @return {*}  {Record<string, any>}
 * @author hzxiongxu
 * @date 20210602
 */
function getAllUrlParams(url) {
    if (url === void 0) { url = window.location.href; }
    var params = {};
    var reg = new RegExp("\\?([^#]+)($|#)", 'i');
    var r = url.match(reg);
    if (r !== null) {
        r[1].split('&').forEach(function (item) {
            var q = item.split('=');
            if (q.length === 2) {
                params[q[0]] = decodeURIComponent(q[1]);
            }
        });
    }
    return params;
}
/**
 *
 * 给url添加参数,不改变参数的顺序，向后追加，如果有同名的则直接更改
 * @export
 * @category  url
 * @param {Record<string, any>} params 添加的参数，允许同时添加多个
 * @param {boolean} [isCover=true] 是否覆盖原来已有的参数，默认为覆盖
 * @param {*} [url=window.location.href] url，默认为当前页面的url
 * @return {*}  {string}
 * @author hzxiongxu
 * @date 20210602
 */
function addUrlParams(params, url, isCover) {
    if (url === void 0) { url = window.location.href; }
    if (isCover === void 0) { isCover = true; }
    var reg = new RegExp("\\?([^#]+)($|#)", 'i');
    var r = url.match(reg);
    // 本来就有参数的case
    if (r !== null) {
        // 如果不覆盖，那就删除现在的参数，不用对象合并的方式，是为了不改变原有的参数顺序
        if (!isCover) {
            for (var key in params) {
                if (("&" + r[1]).indexOf("&" + key + "=") !== -1) {
                    delete params[key];
                }
            }
        }
        return url.replace(/\?[^#]+/, "?" + r[1] + "&" + _ObjectToUrlParams(params));
    }
    else {
        //  默认参数还是不要加到hash上了
        if (url.indexOf('#') === -1) {
            return url + "?" + _ObjectToUrlParams(params);
        }
        else {
            var hashArr = url.split('#');
            return hashArr[0] + "?" + _ObjectToUrlParams(params) + "#" + hashArr[1];
        }
    }
}
/**
 *
 * 从url中删除指定的参数
 * @export
 * @category  url
 * @param {string} key
 * @param {*} [url=window.location.href]
 * @return {*}  {string}
 */
function delUrlParams(key, url) {
    if (url === void 0) { url = window.location.href; }
    var reg = new RegExp("(^|&|\\?)" + key + "=([^&^#]*)", 'i');
    var r = url.match(reg);
    if (r != null) {
        // 如果上一位是“？”不能直接 删除
        if (r[1] === '?') {
            url = url.replace(r[0].substr(1), '');
        }
        else {
            url = url.replace(r[0], '');
        }
    }
    // 删除掉多余的问题
    url = url.replace('?&', '?').replace('?#', '#');
    if (url.substr(-1) === '?') {
        url = url.replace('?', '');
    }
    return url;
}
/**
 *
 *  将对象转成url参数
 * @param {Record<string, any>} params
 * @category  url
 * @private
 * @return {*}  {string}
 * @author hzxiongxu
 * @date 20210602
 */
function _ObjectToUrlParams(params) {
    // 此处的entries 不引入polyfill 不会转义，但是引入变大了，需要放弃此类写法吗？
    return Object.entries(params).reduce(function (initString, _a) {
        var key = _a[0], value = _a[1];
        return initString ? initString + "&" + key + "=" + encodeURIComponent(value) : key + "=" + encodeURIComponent(value);
    }, '');
}

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

/**
 *
 * 金额转换，支持小数点，单位，千分位配置
 * @category  format
 * @param {number} m 输入金额
 * @param {Rule} [rule] interface接口，支持是否使用千分位，
 * @returns {(string|number)}
 * @author hzxiongxu
 * @date 20210602
 *
 */
function moneyFormat(m, rule) {
    if (isNaN(+m)) {
        return m;
    }
    // 默认2位小数加上千分位
    var p = {
        decimalPlaces: 2,
        useThousands: true,
        unit: '',
        symbol: ''
    };
    var params = __assign(__assign({}, p), rule);
    var result = '0.00';
    var fixedNum = Number(m).toFixed(params.decimalPlaces);
    result = params.useThousands ? fixedNum.replace(/\B(?=(\d{3})+\b)/g, ',') : fixedNum;
    return "" + params.symbol + result + params.unit;
}
/**
 * 格式化卡号格式：仅数字，4位一空格 （1111 2222 3333）
 * @format  format
 * @param {string} value
 * @param {number} limit
 * @author hzxiongxu
 * @date 20210602
 */
function cardNoFormat(value, limit) {
    if (limit === void 0) { limit = 25; }
    if (value) {
        var formatValue = value.replace(/[^0-9]/g, '');
        if (limit) {
            formatValue = formatValue.length > limit ? formatValue.slice(0, limit) : formatValue;
        }
        return formatValue.replace(/(\d{4})(?=.)/g, '$1 ');
    }
    return value;
}
/**
 *
 * 格式化手机号格式：仅数字，344分隔 （133 2222 3333）
 * @category format
 * @param {string} value
 * @returns {string}
 * @author hzxiongxu
 * @date 20210602
 *
 */
function mobileNoFormat(value) {
    if (value) {
        var formatValue = value.replace(/[^0-9]/g, '');
        return formatValue.replace(/(\d{3})(?!$)/, '$1 ').replace(/(\d{4})(?!$)/, '$1 ');
    }
    return value;
}
/**
 *
 *
 * 格式化百分数，将小数转成百分数
 * @category format
 * @param {(string | number)} value
 * @param {number} [decimalPlaces=2]
 * @author hzxiongxu
 * @date 20210602
 * @return {*}  {(string | number)}
 */
function percentFormat(value, decimalPlaces) {
    if (decimalPlaces === void 0) { decimalPlaces = 2; }
    if (isNaN(+value)) {
        return value;
    }
    return (+value * 100).toFixed(decimalPlaces) + "%";
}

var ua = window.navigator.userAgent;
var Chrome = /CriOS/i.test(ua) || /Chrome/i.test(ua);
var IOS = /(iPhone|iPad|iPod|iOS)/gi.test(ua);
var WxMiniProgram = /miniprogram/i.test(ua) || window.__wxjs_environment === 'miniprogram';
/**
 * 通过UA判断设备信息,参数请参考DeviceDto接口
 * @type {*}
 * @author hzxiongxu
 * @date 20210524
 *  */
var device = {
    Mobile: /(iPhone|iPad|iPod|iOS|Android|adr|Windows Phone|SymbianOS)/gi.test(navigator.userAgent),
    IOS: IOS,
    Android: /android|adr/gi.test(ua),
    WX: /MicroMessenger/i.test(ua) && !WxMiniProgram,
    Epay: /epay163/gi.test(ua),
    EpayApp: /epay163App/gi.test(ua),
    EpaySDK: /epay163SDK/gi.test(ua),
    Safari: IOS && /Safari/i.test(navigator.userAgent) && !Chrome,
    Chrome: Chrome,
    WxMiniProgram: WxMiniProgram,
    Cbg: /app_cbg/i.test(ua)
};

export { addUrlParams, cardNoFormat, delUrlParams, device, getAllUrlParams, getUrlParams, mobileNoFormat, moneyFormat, percentFormat };
